<?php
/**
 * @version SOFORT Gateway 3.3.0 - $Date: 2012-09-06 13:49:09 +0200 (Thu, 06 Sep 2012) $
 * @author SOFORT AG (integration@sofort.com)
 * @link http://www.sofort.com/
 *
 * Copyright (c) 2012 SOFORT AG
 *
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 *
 * $Id: sofortOrderShopTools.php 5326 2012-09-06 11:49:09Z boehm $
 *
 */


/**
 * get language file
 * @param  string $lng
 * @param  string $paymentMethod
 * @return string
 */
function shopGetLanguageFile($lng, $paymentMethod){
	return DIR_FS_CATALOG.'includes/languages/'.$lng.'/modules/payment/sofort_'.strtolower($paymentMethod).'.php';
}


/**
 * get link to packing slip
 * @return string
 */
function shopGetPackingslipLink(){
	return FILENAME_ORDERS_PACKINGSLIP;
}


/**
 * get link to invoice
 * @return string
 */
function shopGetInvoiceLink(){
	return FILENAME_ORDERS_INVOICE;
}


/**
 * get packing slip text
 * @return string
 */
function shopGetPackingslipText(){
	return IMAGE_ORDERS_PACKINGSLIP;
}


/**
 * get "back" text
 * @return string
 */
function shopGetBackText(){
	return IMAGE_BACK;
}


/**
 * get "invoice" text
 * @return string
 */
function shopGetInvoiceText(){
	return IMAGE_ORDERS_INVOICE;
}


/**
 * get logo for specified sofort-paymentMethod
 * @param  string $paymentMethodShort
 * @return string
 */
function shopGetLogo($paymentMethodShort){
	$str = constant('SOFORT_'.$paymentMethodShort.'_TEXT_TITLE');
	
	return $logo = substr($str, strrpos($str, '<img'));
}


/**
 * get link to top part of orders.php
 * @return string
 */
function shopGetTop(){
	return DIR_FS_CATALOG.'ext/modules/payment/sofort/ressources/scripts/'.HelperFunctions::getIniValue('shopsystemVersion').'_ordersTop.php';
}


/**
 * get link to bottom part of orders.php
 * @return string
 */
function shopGetBottom(){
	return DIR_FS_CATALOG.'ext/modules/payment/sofort/ressources/scripts/'.HelperFunctions::getIniValue('shopsystemVersion').'_ordersBottom.php';
}


/**
 * get tooltip image
 * @return string
 */
function shopGetTooltipImage(){
	return '../ext/modules/payment/sofort/ressources/images/ilink.gif';
}


/**
 * get icon path
 * @return string
 */
function shopGetIconPath(){
	return '../ext/modules/payment/sofort/ressources/images/';
}


/**
 * get config key
 * @return string
 */
function shopGetConfigKey(){
	return SOFORT_MULTIPAY_CONFIGURATION_KEY;
}


/**
 * only return result if it contains exactly 1 row
 * @param  string $query
 * @return boolean
 */
function shopDbCheckAndFetchOne($query){
	$result = tep_db_query($query);
	
	if (tep_db_num_rows($result)==0 || tep_db_num_rows($result)>=2) {
		return false;
	} else {
		return tep_db_fetch_array($result);
	}
}


/**
 * handle and submit status / comment change via orderdetailpage
 * @param int	 $oID
 * @param object $order
 * @param string $status
 * @param string $comments
 * @param string $notifyCustomer
 * @param string $notifyWithComments
 */
function shopSofortComment($oID, $order, $status, $comments, $notifyCustomer, $notifyWithComments){
	global $messageStack;
	
	$order_updated = false;
	$check_status_query = shopDbQuery("SELECT customers_name, customers_email_address, orders_status, date_purchased from ".TABLE_ORDERS." WHERE orders_id = '".(int)$oID."'");
	$check_status = shopDbFetchArray($check_status_query);
	
	if (($check_status['orders_status'] != $status) || tep_not_null($comments)) {
		shopDbQuery("UPDATE ".TABLE_ORDERS." SET orders_status = '".shopDbInput($status)."', last_modified = now() WHERE orders_id = '".(int)$oID."'");
		$customer_notified = '0';
		
		if (isset($notifyCustomer) && ($notifyCustomer == 'on')) {
			$notify_comments = '';
			
			if (isset($notifyWithComments) && ($notifyWithComments == 'on')) $notify_comments = sprintf(EMAIL_TEXT_COMMENTS_UPDATE, $comments)."\n\n";
			
			$email = STORE_NAME."\n".EMAIL_SEPARATOR."\n".EMAIL_TEXT_ORDER_NUMBER.' '.$oID."\n".EMAIL_TEXT_INVOICE_URL.' '.shopCatalogHrefLink(FILENAME_CATALOG_ACCOUNT_HISTORY_INFO, 'order_id='.$oID, 'SSL')."\n".EMAIL_TEXT_DATE_ORDERED.' '.shopDateLong($check_status['date_purchased'])."\n\n".$notify_comments.sprintf(EMAIL_TEXT_STATUS_UPDATE, $orders_status_array[$status]);
			shopDbMail($check_status['customers_name'], $check_status['customers_email_address'], EMAIL_TEXT_SUBJECT, $email, STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS);
			$customer_notified = '1';
		}
		
		shopDbQuery("INSERT INTO ".TABLE_ORDERS_STATUS_HISTORY." (orders_id, orders_status_id, date_added, customer_notified, comments) VALUES ('".(int)$oID."', '".shopDbInput($status)."', now(), '".shopDbInput($customer_notified)."', '".shopDbInput($comments)."')");
		$order_updated = true;
	}
	
	if ($order_updated == true) {
		$messageStack->add_session(SUCCESS_ORDER_UPDATED, 'success');
	} else {
		$messageStack->add_session(WARNING_ORDER_NOT_UPDATED, 'warning');
	}
	
	return;
}

///////////////////////////////////////////////////////
// Following functions only wrap shop-core-functions //
///////////////////////////////////////////////////////

function shopGetTaxRate($class_id){
	return tep_get_tax_rate($class_id);
}


function shopDbQuery($query){
	return tep_db_query($query);
}


function shopDbPerform($table, $data, $action = 'insert', $parameters = '', $link = 'db_link'){
	return tep_db_perform($table, $data, $action, $parameters, $link);
}


function shopDbFetchArray($query){
	return tep_db_fetch_array($query);
}


function shopDbPrepareInput($string){
	return tep_db_prepare_input($string);
}


function shopDbInput($string){
	return tep_db_input($string);
}


function shopDbNumRows($result){
	return tep_db_num_rows($result);
}


function shopDbOutput($string) {
	return tep_db_output($string);
}


function shopAdressFormat($address_format_id, $address, $html, $boln, $eoln){
	return tep_address_format($address_format_id, $address, $html, $boln, $eoln);
}


function shopDisplayTaxValue($value){
	return tep_display_tax_value($value);
}


function shopAddTax($price, $tax){
	return tep_add_tax($price, $tax);
}


function shopDatetimeShort($raw_datetime){
	return tep_datetime_short($raw_datetime);
}


function shopImage($src,$alt){
	return tep_image($src,$alt);
}


function shopDrawForm($name, $action, $parameters){
	return tep_draw_form($name, $action, $parameters);
}


function shopGetAllGetParams($exclude_array){
	return tep_get_all_get_params($exclude_array);
}


function shopDrawTextAreaField($name, $wrap, $width, $height, $text){
	return tep_draw_textarea_field($name, $wrap, $width, $height, $text);
}


function shopDrawCheckboxField($name ,$value, $checked){
	return tep_draw_checkbox_field($name ,$value, $checked);
}


function shopDrawPulldownMenu($name, $values,$default){
	return tep_draw_pull_down_menu($name, $values,$default);
}


function shopDrawRadioField($name, $value, $checked, $parameters = ''){
	return tep_draw_radio_field($name,$value,$checked,$parameters);
}


function shopHrefLink($page, $parameters){
	return tep_href_link($page,$parameters);
}


function shopDbMail($to_name, $to_email_address, $email_subject, $email_text, $from_email_name, $from_email_address){
	tep_mail($to_name, $to_email_address, $email_subject, $email_text, $from_email_name, $from_email_address);
	
	return;
}


function shopCatalogHrefLink($page, $parameters){
	return tep_catalog_href_link($page, $parameters);
}


function shopDateLong($raw_date){
	return tep_date_long($raw_date);
}