<?php
/**
 * @version SOFORT Gateway 3.3.0 - $Date: 2013-01-25 10:10:08 +0100 (Fri, 25 Jan 2013) $
 * @author SOFORT AG (integration@sofort.com)
 * @link http://www.sofort.com/
 *
 * Copyright (c) 2012 SOFORT AG
 *
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 *
 * $Id: sofort_ls.php 5966 2013-01-25 09:10:08Z boehm $
 */

require_once(DIR_FS_CATALOG.'ext/modules/payment/sofort/sofort.php'); // abstract payment module
require_once(DIR_FS_CATALOG.'ext/modules/payment/sofort/library/sofortLib.php');

class sofort_ls extends sofort{
	
	function sofort_ls() {
		global $order;
		
		parent::sofort();
		
		$this->_checkExistingSofortConstants('ls');
		$this->code = 'sofort_ls';
		$this->code_short = 'ls';
		$this->title = SOFORT_LASTSCHRIFT_TEXT_TITLE;
		$this->public_title = SOFORT_LS_TEXT_TITLE;
		$this->paymentMethod = 'LS';
		
		if (defined('SOFORT_LS_RECOMMENDED_PAYMENT') && SOFORT_LS_RECOMMENDED_PAYMENT == 'True') $this->public_title .= ' ' . SOFORT_LS_RECOMMENDED_PAYMENT_TEXT;
		
		$this->enabled = ((defined('SOFORT_LS_STATUS') && SOFORT_LS_STATUS == 'True') ? true : false);
		$this->description = SOFORT_LS_TEXT_DESCRIPTION.'<br />'.SOFORT_MULTIPAY_VERSIONNUMBER.': '.HelperFunctions::getSofortmodulVersion();
		
		if ($this->_isInstalled() && (!defined('SOFORT_MULTIPAY_MODULE_VERSION') || strcasecmp(trim(SOFORT_MULTIPAY_MODULE_VERSION), trim(HelperFunctions::getSofortmodulVersion())) != 0)) {
			$this->description = '<span style ="color:red; font-weight: bold; font-size: 1.2em">'.SOFORT_MULTIPAY_UPDATE_NOTICE.'</span><br /><br />'.$this->description;
		}
		
		$this->description .= SOFORT_LS_TEXT_DESCRIPTION_EXTRA;
		$this->sort_order = (defined('SOFORT_LS_SORT_ORDER') ? SOFORT_LS_SORT_ORDER : false);
		
		if (is_object($order)) $this->update_status();
		
		if (defined('SOFORT_LS_STATUS')) {
			$this->sofort = new SofortLib_Multipay(SOFORT_MULTIPAY_CONFIGURATION_KEY);
			$this->sofort->setVersion(HelperFunctions::getSofortmodulVersion());
			
			if (defined('SOFORT_MULTIPAY_LOG_ENABLED') && SOFORT_MULTIPAY_LOG_ENABLED == "True") $this->sofort->setLogEnabled();
		}
	}
	
	
	function selection() {
		global $order;
		
		if (!parent::selection()) {
			$this->sofort->log("Notice: Paymentmethod ".$this->code." will be deactivated for selection.");
			$this->enabled = false;
			
			return false;
		}
		
		$fields = array(
				array(
						'title' => SOFORT_LS_TEXT_HOLDER,
						'field' => tep_draw_input_field('ls_sender_holder', array_key_exists('ls_sender_holder', $_SESSION['sofort']) ? strip_tags($_SESSION['sofort']['ls_sender_holder']) : strip_tags($order->billing['firstname'] . ' ' . $order->billing['lastname']))),
				array(
						'title' => SOFORT_LS_TEXT_ACCOUNT_NUMBER,
						'field' => tep_draw_input_field('ls_account_number', array_key_exists('ls_account_number', $_SESSION['sofort']) ? strip_tags($_SESSION['sofort']['ls_account_number']) : '')),
				array(
						'title' => SOFORT_LS_TEXT_BANK_CODE,
						'field' => tep_draw_input_field('ls_bank_code', array_key_exists('ls_bank_code', $_SESSION['sofort']) ? strip_tags($_SESSION['sofort']['ls_bank_code']) : '')),
				array(
						'title' => SOFORT_LS_CHECKOUT_CONDITIONS,
						'field' => tep_draw_checkbox_field('sofort_conditions_ls', 'sofort_conditions_ls'))
		);
		
		return array('id' => $this->code , 'module' => $this->public_title , 'fields' => $fields);
	}
	
	
	function pre_confirmation_check() {
		parent::pre_confirmation_check();
		
		$requestData = $_POST;
		
		$_SESSION['sofort']['ls_sender_holder']     = trim($requestData['ls_sender_holder']);
		$_SESSION['sofort']['ls_account_number']    = trim($requestData['ls_account_number']);
		$_SESSION['sofort']['ls_bank_code']         = trim($requestData['ls_bank_code']);
		$requestData['sofort_conditions_ls']        = trim($requestData['sofort_conditions_ls']);
		$_SESSION['sofort']['sofort_conditions_ls'] = isset($requestData['sofort_conditions_ls']) ? $requestData['sofort_conditions_ls'] : '';
		
		$errorCodes = array();
		$errorFound = false;
		
		if ($_SESSION['sofort']['sofort_conditions_ls'] != 'sofort_conditions_ls') {
			$errorFound = true;
			$errorCodes[] = '10002';
		}
		
		if (!$_SESSION['sofort']['ls_sender_holder'] || !$_SESSION['sofort']['ls_account_number'] || !$_SESSION['sofort']['ls_bank_code']) {
			$errorFound = true;
			$errorCodes[] = '10001';
		}
		
		if ($errorFound) {
			$errorString = '&payment_error='.$this->code.'&error_codes='.implode(',', $errorCodes);
			$redirectUrl = tep_href_link(FILENAME_CHECKOUT_PAYMENT, $errorString, 'SSL', true, false);
			tep_redirect(HelperFunctions::cleanUrlParameter($redirectUrl));
		}
		
		return false;
	}
	
	
	function confirmation() {
		$fields = array(
			array(
					'title' => SOFORT_LS_TEXT_HOLDER,
					'field' => $_SESSION['sofort']['ls_sender_holder']
			),
			array(
					'title' => SOFORT_LS_TEXT_ACCOUNT_NUMBER,
					'field' => $_SESSION['sofort']['ls_account_number']
			),
			array(
					'title' => SOFORT_LS_TEXT_BANK_CODE,
					'field' => $_SESSION['sofort']['ls_bank_code']
			)
		);
		
		return parent::confirmation(SOFORT_LS_CHECKOUT_CONFIRMATION, $fields);
	}
	function install() {
		$sofortStatuses = $this->_insertAndReturnSofortStatus();
		$refundedStatus = (isset($sofortStatuses['refunded']) && !empty($sofortStatuses['refunded'])) ? $sofortStatuses['refunded'] : '';
		$unchangedStatus = (isset($sofortStatuses['unchanged']) && !empty($sofortStatuses['unchanged'])) ? $sofortStatuses['unchanged'] : '';
		$directDebitStatus = (isset($sofortStatuses['direct_debit']) && !empty($sofortStatuses['direct_debit'])) ? $sofortStatuses['direct_debit'] : '';
		$returnedDebitStatus = (isset($sofortStatuses['returned_debit']) && !empty($sofortStatuses['returned_debit'])) ? $sofortStatuses['returned_debit'] : '';
		
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LS_STATUS_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LS_STATUS_DESC)."', 'SOFORT_LS_STATUS', 'False', '6', '1', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LS_SORT_ORDER_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LS_SORT_ORDER_DESC)."', 'SOFORT_LS_SORT_ORDER', '0', '6', '16', now())");
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LS_RECOMMENDED_PAYMENT_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LS_RECOMMENDED_PAYMENT_DESC)."', 'SOFORT_LS_RECOMMENDED_PAYMENT', 'False', '6', '5', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LASTSCHRIFT_ALLOWED_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LASTSCHRIFT_ALLOWED_DESC)."', 'SOFORT_LASTSCHRIFT_ALLOWED', '', '6', '12', now())");
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LS_ZONE_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LS_ZONE_DESC)."', 'SOFORT_LS_ZONE', '0', '6', '13', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");
		
		//"Bestätigt - Bisher kein Geldeingang" - pending-not_credited_yet
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LS_PEN_NOT_CRE_YET_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LS_PEN_NOT_CRE_YET_STATUS_ID_DESC)."', 'SOFORT_LS_PEN_NOT_CRE_YET_STATUS_ID', '".HelperFunctions::escapeSql($directDebitStatus)."',  '6', '35', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//"Rücklastschrift" - loss-rejected
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LS_LOS_REJ_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LS_LOS_REJ_STATUS_ID_DESC)."', 'SOFORT_LS_LOS_REJ_STATUS_ID', '".HelperFunctions::escapeSql($returnedDebitStatus)."',  '6', '35', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//"Geldeingang" - received-credited
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LS_REC_CRE_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LS_REC_CRE_STATUS_ID_DESC)."', 'SOFORT_LS_REC_CRE_STATUS_ID', '".HelperFunctions::escapeSql($unchangedStatus)."',  '6', '35', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//"Teilrückbuchung" - refunded-compensation
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LS_REF_COM_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LS_REF_COM_STATUS_ID_DESC)."', 'SOFORT_LS_REF_COM_STATUS_ID', '".HelperFunctions::escapeSql($unchangedStatus)."',  '6', '35', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//"Vollständige Rückbuchung" - refunded-refunded
		tep_db_query("INSERT INTO ".TABLE_CONFIGURATION." (configuration_title, configuration_description, configuration_key, configuration_value,  configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('".HelperFunctions::escapeSql(SOFORT_LS_REF_REF_STATUS_ID_TITLE)."', '".HelperFunctions::escapeSql(SOFORT_LS_REF_REF_STATUS_ID_DESC)."', 'SOFORT_LS_REF_REF_STATUS_ID', '".HelperFunctions::escapeSql($refundedStatus)."',  '6', '35', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
		
		//install shared keys, that are used by all/most multipay-modules
		parent::install();
	}
	
	
	function remove() {
		tep_db_query("delete from ".TABLE_CONFIGURATION." where configuration_key LIKE 'SOFORT_LS%'");
		tep_db_query("delete from ".TABLE_CONFIGURATION." where configuration_key LIKE 'SOFORT_LASTSCHRIFT%'");
		
		parent::remove();
	}

	function keys() {
		parent::keys();
		
		return array(
			'SOFORT_LS_STATUS',
			'SOFORT_MULTIPAY_CONFIGURATION_KEY',
			'SOFORT_MULTIPAY_AUTH',
			'SOFORT_LS_RECOMMENDED_PAYMENT',
			'SOFORT_MULTIPAY_REASON_1',
			'SOFORT_MULTIPAY_REASON_2',
			'SOFORT_LASTSCHRIFT_ALLOWED',
			'SOFORT_LS_ZONE',
			'SOFORT_LS_SORT_ORDER',
			'SOFORT_MULTIPAY_PROF_SETTINGS',
			'SOFORT_MULTIPAY_TEMP_STATUS_ID',
			'SOFORT_MULTIPAY_ABORTED_STATUS_ID',
			'SOFORT_LS_PEN_NOT_CRE_YET_STATUS_ID',
			'SOFORT_LS_LOS_REJ_STATUS_ID',
			'SOFORT_LS_REC_CRE_STATUS_ID',
			'SOFORT_LS_REF_COM_STATUS_ID',
			'SOFORT_LS_REF_REF_STATUS_ID',
			//'SOFORT_MULTIPAY_LOG_ENABLED',
		);
	}
}
?>